@@ -2,7 +2,7 @@ import time
 from .read_trex_config import LoadTRExConfig
 from .load_servicex_requests import LoadServiceXRequests
 from .communicate_servicex import ServiceXFrontend
-from .make_ntuples import make_ntuples
+from .make_ntuples import MakeNtuples
 
 
 class ServiceXTRExFitter:
@@ -35,6 +35,9 @@ class ServiceXTRExFitter:
         # Load ServiceX requests
         requests = self._servicex_requests.__dict__['_servicex_requests']
 
+        # Exit if no GridDID for all Sample
+        if len(requests) == 0: return print("No ServiceX request made - no Sample with GridDID")
+
         # Configure ServiceX Frontend to connect ServiceX backend
         sx = ServiceXFrontend(requests)
 
@@ -44,7 +47,8 @@ class ServiceXTRExFitter:
         times.update({'t1': time.monotonic()})
 
         # Produce ROOT ntuples
-        output_path = make_ntuples(self._trex_config, requests, output_parquet_list)
+        mn = MakeNtuples(self._trex_config)
+        output_path = mn.make_ntuples(requests, output_parquet_list)
         times.update({'t2': time.monotonic()})
 
         if timer:
